from distutils.core import setup
setup   (
	name		='fabu',
	version		='1.2.0',
	py_modules	=['qiantao'],
	author		='hfpython',
	author_email	='hfpython@headfirstlabs.com',
	url		='http://www.headfirstlabs.com',
	description	='A simple printer of nester lists',
	)
